@@ -8,7 +8,7 @@ use warnings;
 use Moo;
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 has node => (
     is       => 'ro',
@@ -26,14 +26,11 @@ has table => (
     },
 );
 
-around new => sub {
-    my ($code,$class,@arg) = @_;
 
-    my $obj = $code->($class, @arg);
-    $obj->_parse;
-
-    return $obj;
-};
+sub BUILD {
+    my $self = shift;
+    $self->_parse;
+}
 
 has id   => ( is => 'rwp' );
 has name => ( is => 'rwp' );
@@ -98,7 +95,9 @@ MySQL::Workbench::Parser::Index - An index of the ER model
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=for Pod::Coverage BUILD
 
 =head2 as_hash
 
