@@ -13,7 +13,7 @@ use YAML::Tiny;
 use MySQL::Workbench::Parser::Column;
 use MySQL::Workbench::Parser::Index;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 has node => (
     is       => 'ro',
@@ -86,14 +86,11 @@ has column_mapping => (
     },
 );
 
-around new => sub {
-    my ($code,$class,@arg) = @_;
 
-    my $obj = $code->($class, @arg);
-    $obj->_parse;
-
-    return $obj;
-};
+sub BUILD {
+    my $self = shift;
+    $self->_parse;
+}
 
 
 sub as_hash {
@@ -235,7 +232,9 @@ MySQL::Workbench::Parser::Table - A table of the ER model
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=for Pod::Coverage BUILD
 
 =head2 as_hash
 
